@@ -3,7 +3,7 @@ package  XML::RelaxNG::Compact::PXB;
 use strict;
 use warnings;
 use English qw( -no_match_vars);
-use version; our $VERSION = '0.13';
+use version; our $VERSION = '0.14';
 
 
 =head1 NAME
@@ -12,7 +12,7 @@ XML::RelaxNG::Compact::PXB  -   create perl XML (RelaxNG Compact) data binding A
 
 =head1 VERSION
 
-Version 0.13
+Version 0.14
 
 =head1 DESCRIPTION
 
@@ -77,7 +77,8 @@ See L<XML::RelaxNG::Compact::DataModel> for more details and examples.
 
       ####
 
-      #### this call will build only Helper modules under /topdir/API/Datatypes/v1_0/ -  namespace prefix mapping, basic element operations
+      #### this call will build only Helper modules under /topdir/API/Datatypes/v1_0/ -  
+      #### namespace prefix mapping, basic element operations
       ####
       
       $api_builder->buildHelpers();
@@ -97,7 +98,8 @@ use POD::Credentials;
 use Class::Accessor::Fast;
 use Class::Fields;
 use base qw(Class::Accessor::Fast Class::Fields);
-use fields qw(debug top_dir datatypes_root project_root schema_version test_dir footer nsregistry _schema_version_dir  _TESTS  _fh _fhtest  _path  _root _known_class _existed DEBUG);
+use fields qw(debug top_dir datatypes_root project_root schema_version test_dir footer nsregistry 
+              _schema_version_dir  _TESTS  _fh _fhtest  _path  _root _known_class _existed DEBUG);
 XML::RelaxNG::Compact::PXB->mk_accessors(XML::RelaxNG::Compact::PXB->show_fields('Public'),'_fh', '_fhtest', '_TESTS');
 
 =head2 new({})
@@ -175,7 +177,7 @@ Possible ways to call B<new()>:
 #  XSD/XSI namespaces
 
 our $XSD_NS = {'xsd'=>"http://www.w3.org/2001/XMLSchema",
-                'xsi' => "http://www.w3.org/2001/XMLSchema-instance",
+               'xsi' => "http://www.w3.org/2001/XMLSchema-instance",
               };
 
 sub new {
@@ -210,7 +212,7 @@ sub new {
         $self->nsregistry($XSD_NS);
     }
     $self->footer->end_module(1);
-    $self->footer->see_also(' Automatically generated by L<XML::RelaxNG::Compact::PXB> ');
+    $self->footer->see_also(' Automatically generated by L<XML::RelaxNG::Compact::PXB> ') unless $self->footer->see_also;
     return $self;
 }
 
@@ -226,12 +228,16 @@ sub new {
 sub  _makeAPIPath {
     my ($self, $classname,  $ns) = @_;
     my $classnameUP = ucfirst($classname);
-    print "MakePath:  ::$ns  packagepath=" . $self->_packagePath . "  classnameUP=$classnameUP\n" if $self->DEBUG > 1;
+    print "MakePath:  ::$ns  packagepath=" . $self->_packagePath .
+          "  classnameUP=$classnameUP\n" if $self->DEBUG > 1;
     push @{$self->{_path}}, $classnameUP;
-    unless ( $self->{_existed}->{$self->project_root . "::" . $self->datatypes_root . "::" . $self->{_schema_version_dir} . "::$ns". $self->_packagePath  }) {
-     
-        $self->{_existed}->{$self->project_root . "::" . $self->datatypes_root . "::" .  $self->{_schema_version_dir} . "::$ns" . $self->_packagePath} =  $classname;
-        $self->{_known_class}->{$classname}{$ns} =  $self->project_root . "::" . $self->datatypes_root . "::" .$self->{_schema_version_dir}  . "::$ns" . $self->_packagePath ;       
+    my $classname_tmp = $self->project_root . "::" . 
+                        $self->datatypes_root . "::" .  
+		        $self->{_schema_version_dir} . "::$ns" . 
+		        $self->_packagePath;
+    unless ( $self->{_existed}->{$classname_tmp} ) {
+        $self->{_existed}->{$classname_tmp} =  $classname;
+        $self->{_known_class}->{$classname}{$ns} = $classname_tmp;       
     }
     return $self;
 }
@@ -301,18 +307,20 @@ sub buildAPI {
     my $parent  =  $param->{parent};
     $self->_printHelpers unless $parent;
     
-    my $ns = $element->{attrs}->{xmlns};
-    croak(" Malformed definition: something is  missing name=$name  ns=$ns  element=" .  Dumper $element  ) unless $name && $ns && $element;  
+    my  $ns = $element->{attrs}->{xmlns};
+    croak(" Malformed definition: something is  missing name=$name  ns=$ns  element=" .  Dumper $element) 
+        unless $name && $ns && $element;  
     $self->_makeAPIPath($name,  $ns);
     if($element && ref($element) eq 'HASH' &&  $element->{attrs})  {
-        if(ref($element->{elements}) eq 'ARRAY') {
-            mkpath([ $self->top_dir . "/" . $self->project_root . "/". $self->datatypes_root .  "/"  .$self->{_schema_version_dir} . "/$ns". $self->_dirPath], 1, 0755) unless $self->_TESTS;
+        if(ref($element->{elements}) eq 'ARRAY' && !$self->_TESTS) {
+            mkpath([$self->top_dir . "/" . $self->project_root . "/". $self->datatypes_root .  "/"  . 
+	            $self->{_schema_version_dir} . "/$ns". $self->_dirPath], 1, 0755);
         }
         ###  
         foreach my $el (@{$element->{elements}}) {
             if(ref($el) eq 'ARRAY') {
                 if(ref($el->[1]) eq 'HASH' && $el->[1]->{attrs}) {
-                    $self->buildAPI({name => $el->[0],  element => $el->[1], parent => $element}); 
+                    $self->buildAPI({name => $el->[0], element => $el->[1], parent => $element}); 
                 } elsif(ref($el->[1]) eq 'ARRAY') {
                     foreach my $sub_el (@{$el->[1]}) { ### if right part is arrayref - means choice between elements
                         next unless $sub_el;
@@ -321,22 +329,22 @@ sub buildAPI {
                         } elsif(ref($sub_el) eq 'ARRAY' && scalar @{$sub_el} == 1) {  # choice between multiple
                             $self->buildAPI({name => $el->[0],  element => $sub_el->[0], parent => $element});
                         } else {
-                            croak(" Malformed definition: name=" . $el->[0] ." sub_el Dump=" . Dumper($sub_el) . " el Dump=" .  Dumper  $el );
+                            croak(" Malformed definition: name=" . $el->[0] .
+			          " sub_el Dump=" . Dumper($sub_el) . " el Dump=" . Dumper  $el);
                         }
                     }
                 }
             }
-        }
- 
-       $self->buildClass($name, $element, $parent) if defined $self->_dirPath && defined $self->_packagePath;
-       # if empty directory was created, then remove it
-       my $child_dir =  $self->top_dir ."/". $self->project_root . "/". $self->datatypes_root . "/" . $self->{_schema_version_dir} . "/$ns". $self->_dirPath;
-       rmdir $child_dir  if( -d   $child_dir); 
-       pop @{$self->{_path}} if  defined $self->_dirPath && defined $self->_packagePath;   
+        } 
+        $self->buildClass($name, $element, $parent) if defined $self->_dirPath && defined $self->_packagePath;
+        # if empty directory was created, then remove it
+        my $child_dir =  $self->top_dir ."/". $self->project_root . "/". $self->datatypes_root . "/" . 
+                        $self->{_schema_version_dir} . "/$ns". $self->_dirPath;
+        rmdir $child_dir  if( -d   $child_dir); 
+        pop @{$self->{_path}} if  defined $self->_dirPath && defined $self->_packagePath;   
     } else {
         croak("Malformed definition: ended up in non element");
-    }
-   
+    }  
     return $self;
 }
 
@@ -353,7 +361,6 @@ sub buildHelpers {
      return $self;
 }
 
-
 =head2 buildAM
 
  prints accessors and mutators for the passed reference to array of names
@@ -361,10 +368,10 @@ sub buildHelpers {
 
 =cut
 
-
 sub buildAM {
     my ($self, $arr_names) = @_;
-    croak " Only array ref parameter accepted" . Dumper $arr_names  unless ref($arr_names) eq 'ARRAY';
+    croak(" Only array ref parameter accepted" . Dumper $arr_names)  
+        unless ref($arr_names) eq 'ARRAY';
     foreach my $name (@{$arr_names}) {
         $self->sayIt(qq"
 
@@ -410,7 +417,6 @@ sub buildTests {
      $self->_TESTS(1);
      $self->buildAPI(@_);
      return $self;
-
 }
 
 =head2 buildClass
@@ -442,9 +448,11 @@ returns $self
     my ($self, $name, $element, $parent) = @_;
     # current path
     my $ns = $element->{attrs}->{xmlns};
-    my $path = $self->top_dir ."/".  $self->project_root . "/". $self->datatypes_root . "/" . $self->{_schema_version_dir} . "/$ns" .  $self->_dirPath;
+    my $path = $self->top_dir ."/".  $self->project_root . "/". $self->datatypes_root . "/" . 
+               $self->{_schema_version_dir} . "/$ns" .  $self->_dirPath;
     # current classname
-    my $root =  $self->project_root . "::". $self->datatypes_root . "::" . $self->{_schema_version_dir}  . "::$ns".  $self->_packagePath;
+    my $root =  $self->project_root . "::". $self->datatypes_root . "::" . 
+                $self->{_schema_version_dir}  . "::$ns".  $self->_packagePath;
     my $className =   $root;
 
 #--------------------------- some preparatory work here, lists of element names, attributes, text elements -----------
@@ -499,9 +507,7 @@ returns $self
     #-------------------------------------------- build tests
     $self->buildTest(\@elementnodes,  \@attributes, $className, $name, $element);
     # return if TESTS is set - only test files should be built
-    if($self->_TESTS) {
-        return;
-    }
+    return if($self->_TESTS);
 
     $self->_fh(IO::File->new($path . ".pm","w+"));
     croak(" Failed to open file :" . $path . ".pm")  unless $self->_fh;
@@ -587,7 +593,8 @@ use Readonly;
 
     foreach my $el (@elementnodes) {
         foreach my $ns (keys %{$self->{_known_class}->{$el->[0]}}) {
-              $self->sayIt("use " . $self->{_known_class}->{$el->[0]}{$ns} . ";")  if $self->{_known_class}->{$el->[0]}{$ns};
+            $self->sayIt("use " . $self->{_known_class}->{$el->[0]}{$ns} . ";")  
+	        if $self->{_known_class}->{$el->[0]}{$ns};
         }
     }
 
@@ -599,11 +606,11 @@ use Readonly;
 \=head2 new({})
 
  creates   object, accepts DOM with element's tree or hashref to the list of
- keyd parameters:
+ keyed parameters:
 /);
 
-    map { $self->sayIt("         $_   => undef,")  }  @attributes ;
-    map { $self->sayIt("         " . $_->[0]  . " => " . ref($_->[1]) . ",")   }  @elementnodes;
+    map {$self->sayIt("         $_   => undef,")}  @attributes ;
+    map {$self->sayIt("         " . $_->[0]  . " => " . ref($_->[1]) . ",")}  @elementnodes;
 
     $self->sayIt(" text => 'text'") if $element->{text};
 
@@ -620,7 +627,7 @@ sub new {
     my (\$that, \$param) = \@_;
     my \$class = ref(\$that) || \$that;
     my \$self =  fields::new(\$class );
-    \$self->set_LOGGER(get_logger( \$CLASSPATH ));
+    \$self->set_LOGGER(get_logger(\$CLASSPATH));
     \$self->set_nsmap($localized_path\::NSMap->new());
     \$self->get_nsmap->mapname(\$LOCALNAME, '$ns');
 /);
@@ -650,7 +657,6 @@ sub new {
         }
         \$self->get_LOGGER->debug(\"Parsing parameters: \" . (join ' : ', keys \%{\$param}));
 
-
         foreach my \$param_key (keys \%{\$param}) {
             \$self->{\$param_key} = \$param->{\$param_key} if \$self->can(\"get_\$param_key\");
         }
@@ -706,9 +712,9 @@ sub getDOM {
 ###              or    [name => [obj1,obj2]]     -   choice between two obj
 ###              or    [name => [[obj1],[obj2]]] -   choice between two obj arrayref
 ###
-
     foreach my $els (@elementnodes) {
-        croak(" Malformed elements declaration: name=$name  and this thingy: els=$els must be an ARRAY ref ") unless ref($els) eq 'ARRAY';
+        croak(" Malformed elements declaration: name=$name  and this thingy: els=$els must be an ARRAY ref ") 
+	    unless ref($els) eq 'ARRAY';
 
         my  $condition =  _conditionParser($els->[2]);
         my $subname =  $els->[0];
@@ -735,28 +741,26 @@ sub getDOM {
             my  \$domtext  =  getElement({name => \$textnode,
                                           parent => \$$name,
                                           ns => [\$self->get_nsmap->mapname(\$LOCALNAME)],
-                                         text => \$self->{\$textnode},
+                                          text => \$self->{\$textnode},
                               });
-           \$domtext?\$$name->appendChild(\$domtext):\$self->get_LOGGER->logdie("Failed to append new text element \$textnode  to  $name");
+           \$domtext?\$$name->appendChild(\$domtext):
+	             \$self->get_LOGGER->logdie("Failed to append new text element \$textnode to $name");
         }
     }
         !);
     }
     $self->sayIt("      return \$$name;\n}");
 
-
 ### print accessors/mutators for all element nodes and attributes ( careless about the type of the element )
-
-    $self->buildAM(['LOGGER', 'nsmap', 'idmap', 'text',   @attributes, map { $_->[0] } @elementnodes, @textnodes]);
+    $self->buildAM(['LOGGER', 'nsmap', 'idmap', 'text',   @attributes, 
+                       map { $_->[0] } @elementnodes, @textnodes]);
 
 ###  next building various element related methods
-
     foreach my  $el (@elementnodes) {
         my $subname = $el->[0];
         if(ref($el->[1]) eq 'ARRAY') {
             $self->sayIt(qq/
 
-
 \=head2  add\u${subname}()
 
  if any of subelements can be an array then this method will provide
@@ -772,7 +776,8 @@ sub getDOM {
 sub add\u${subname} {
     my (\$self,\$new) = \@_;
 
-    \$self->get_$subname && ref(\$self->get_$subname) eq 'ARRAY'?push \@{\$self->get_$subname}, \$new:\$self->set_$subname([\$new]);
+    \$self->get_$subname && ref(\$self->get_$subname) eq 'ARRAY'?push \@{\$self->get_$subname}, \$new:
+                                                                 \$self->set_$subname([\$new]);
     \$self->get_LOGGER->debug("Added new to $subname");
     \$self->buildIdMap; ## rebuild index map
     return \$self->get_$subname;
@@ -790,7 +795,8 @@ sub add\u${subname} {
 
 sub remove\u${subname}ById {
     my (\$self, \$id) = \@_;
-    if(ref(\$self->get_$subname) eq 'ARRAY' && \$self->get_idmap->{$subname} &&  exists \$self->get_idmap->{$subname}{\$id}) {
+    if(ref(\$self->get_$subname) eq 'ARRAY' && \$self->get_idmap->{$subname} &&  
+       exists \$self->get_idmap->{$subname}{\$id}) {
         undef \$self->get_$subname->\[\$self->get_idmap->{$subname}{\$id}\];
         my \@tmp =  grep { defined \$_ } \@{\$self->get_$subname};
         \$self->set_$subname([\@tmp]);
@@ -816,7 +822,8 @@ sub remove\u${subname}ById {
 sub get\u${subname}ById {
     my (\$self, \$id) = \@_;
 
-    if(ref(\$self->get_$subname) eq 'ARRAY' && \$self->get_idmap->{$subname} && exists \$self->get_idmap->{$subname}{\$id} ) {
+    if(ref(\$self->get_$subname) eq 'ARRAY' && \$self->get_idmap->{$subname} && 
+       exists \$self->get_idmap->{$subname}{\$id} ) {
         return \$self->get_$subname->\[\$self->get_idmap->{$subname}{\$id}\];
     } elsif(!ref(\$self->get_$subname) || ref(\$self->get_$subname) ne 'ARRAY')  {
         return \$self->get_$subname;
@@ -825,11 +832,8 @@ sub get\u${subname}ById {
     return;
 }
             /);
-
         }
-
     }
-
     $self->sayIt(qq/
 
 \=head2  querySQL ()
@@ -839,8 +843,7 @@ sub get\u${subname}ById {
  
  Accepts one optional parameter - query hashref, it will fill this hashref
  
- will return:
-    
+ will return:    
     { <table_name1> =>  {<field name1> => <value>, ...},...}
 
 \=cut
@@ -848,7 +851,6 @@ sub get\u${subname}ById {
 sub  querySQL {
     my (\$self, \$query) = \@_;
 /);
-#
 #   print hash with mapped fields for this class
 #
     if($element->{sql}) {
@@ -912,8 +914,8 @@ sub  querySQL {
         my $if_sub_cond = ' if    ';
         foreach my  $subname  (@attributes, 'text') {
             if($sql_here{$subname})  {
-               $self->sayIt(_getSQLSub($sql_here{$subname}, $subname, $if_sub_cond));
-               $if_sub_cond =  ' elsif ';
+                $self->sayIt(_getSQLSub($sql_here{$subname}, $subname, $if_sub_cond));
+                $if_sub_cond =  ' elsif ';
             }
         }
         $self->sayIt(qq/
@@ -931,10 +933,8 @@ sub  querySQL {
     }
     $self->sayIt("    return \$query;");
     $self->sayIt("}");
-
     $self->sayIt(qq/
 
-
 \=head2  buildIdMap()
 
  if any of subelements has id then get a map of it in form of
@@ -946,7 +946,6 @@ sub  buildIdMap {
     my \$self = shift;
     my \%map = ();
     /);
-
     if( @elementnodes ) {
         $self->sayIt(qq"
     foreach my \$field (qw/$elements_names/) {
@@ -965,8 +964,7 @@ sub  buildIdMap {
      } else {
         $self->sayIt("    return;");
     }
-    $self->sayIt("}");
-  
+    $self->sayIt("}");  
     $self->sayIt(qq/
 \=head2  asString()
 
@@ -992,7 +990,6 @@ sub asString {
 
 sub registerNamespaces {
     my (\$self, \$nsids) = \@_;
-
     my \$local_nss = {reverse \%{\$self->get_nsmap->mapname}};
     unless(\$nsids) {
         \$nsids = \$local_nss;
@@ -1035,9 +1032,10 @@ sub fromDOM {
     foreach my $attr (@attributes) {
         print("  fromDOM for:  "  . Dumper $element->{attrs}) if $self->DEBUG>2;
         $self->sayIt($self->_printConditional($attr, $element->{attrs}->{$attr}, 'set'));
-        $self->sayIt("    \$self->get_LOGGER->debug(\" Attribute $attr= \". \$self->get_$attr) if \$self->get_$attr;");
+        $self->sayIt("    \$self->get_LOGGER->debug(\"Attribute $attr= \". \$self->get_$attr) if \$self->get_$attr;");
     }
-    $self->sayIt($self->_printConditional('text', $element->{text}, 'set')) if ($element->{text});
+    $self->sayIt($self->_printConditional('text', $element->{text}, 'set')) 
+        if ($element->{text});
     if(@elements) {
         $self->sayIt(qq/    foreach my \$childnode (\$dom->childNodes) {
         my  \$getname  = \$childnode->getName;
@@ -1047,8 +1045,9 @@ sub fromDOM {
 	/);
         my $conditon_head =  '     if';
         foreach my $els (@elementnodes) {
-            croak(" Element must be an array ref here: name=$name els=$els ") unless ref($els) eq 'ARRAY';
-	    print " fromDOM subelement: " . Dumper $els if $self->DEBUG > 3;
+            croak("Element must be an array ref here: name=$name els=$els") 
+	        unless ref($els) eq 'ARRAY';
+	    print "fromDOM subelement: " . Dumper $els if $self->DEBUG > 3;
             my $subname =  $els->[0];
             my  $condition  =  _conditionParser($els->[2]);
             $condition->{logic} .= " && " if  $condition->{logic};
@@ -1068,8 +1067,7 @@ sub fromDOM {
                         }
                     }
                 } else {
-		    my $sub_el =  ref $els->[1]->[0] eq 'ARRAY'?$els->[1]->[0]->[0]:$els->[1]->[0];
-		    
+		    my $sub_el =  ref $els->[1]->[0] eq 'ARRAY'?$els->[1]->[0]->[0]:$els->[1]->[0];		    
 		    print " fromDOM 0 from sub_subelement: " . Dumper  $els->[1]->[0]  if $self->DEBUG > 3;
                     $self->_printFromDOM($subname,  $sub_el, 'ARRAY',$conditon_head, $condition->{logic});
                 }
@@ -1084,7 +1082,8 @@ sub fromDOM {
             $self->sayIt("        }");
         }
 #        if(@elementnodes || @textnodes) {
-#            $self->sayIt("       \$dom->removeChild(\$childnode); ##remove processed element from the current DOM so subclass can deal with remaining elements\n";
+#            $self->sayIt("       \$dom->removeChild(\$childnode); 
+##               remove processed element from the current DOM so subclass can deal with remaining elements\n";
 #        }
         $self->sayIt("    }");
         $self->sayIt("    \$self->buildIdMap;\n    \$self->registerNamespaces;");
@@ -1094,8 +1093,6 @@ sub fromDOM {
     $self->_fh->close;
     return;
 }
-
-#
 #
 #   internal call to create perlcritic and perltidy configs
 #
@@ -1128,9 +1125,8 @@ sub _placeCritidy {
         });
     }
     unless( -e  "$basename/perlcritic") {
-      $self->_fh(IO::File->new("$basename/perlcritic",'w+')); 
-    
-       $self->sayIt(qq{
+        $self->_fh(IO::File->new("$basename/perlcritic",'w+'));
+        $self->sayIt(qq{
     severity = 2
     only = 1
     theme = (pbp + core + bugs + readability)
@@ -1182,9 +1178,6 @@ sub _placeCritidy {
     return;
 }
 
-
-
-
 =head2  buildTest
 
  auxiliary method
@@ -1196,7 +1189,6 @@ sub _placeCritidy {
        class name
        name of the package
        element name
-
  returns: nothing
 
 =cut
@@ -1205,9 +1197,9 @@ sub buildTest {
     my ($self, $elementnodes, $attributes, $className, $name, $element) = @_;
     
     my $relative_path = $self->top_dir . '/'.  $self->test_dir;
-    mkpath   ([  $relative_path  ], 1, 0755);
-    mkpath   ([  "$relative_path/conf"], 1, 0755);
-    print " Creating perlcritic and perltidyrc config files ... " if $self->DEBUG > 0;
+    mkpath ([  $relative_path  ], 1, 0755);
+    mkpath ([  "$relative_path/conf"], 1, 0755);
+    print "Creating perlcritic and perltidyrc config files ... " if $self->DEBUG > 0;
     $self->_placeCritidy();
     print " Creating simple test.pl file " if $self->DEBUG > 0;
     unless(-e  $self->top_dir . "/test.pl") {
@@ -1222,7 +1214,6 @@ BEGIN \{
    unshift \@INC, "\$Bin" ; 
    unshift \@INC, "\$Bin/../";  
 \};
- 
 
 if (\$ARGV[0] && \$ARGV[0] eq '-v') \{
   \$Test::Harness::Verbose = 1;
@@ -1235,9 +1226,9 @@ Test::Harness::runtests(<\$Bin/t/*.t>);
     print " Creating test suit... " if $self->DEBUG > 0;
     (my $test_filename = $className) =~ s/(\w)\:\:(\w)/$1\_\_$2/g;
     $self->_fh(IO::File->new("$relative_path/$test_filename.t" ,"w+"));
-    croak(" Failed to open test suite file: $! $relative_path/$test_filename.t")  unless $self->_fh;
-    my $test_number = 2;
-    
+    croak(" Failed to open test suite file: $! $relative_path/$test_filename.t")  
+        unless $self->_fh;
+    my $test_number = 2;  
     my $ns = $element->{attrs}->{xmlns};
     $self->sayIt(qq/
 
@@ -1253,10 +1244,8 @@ use English qw( -no_match_vars);
     $self->sayIt(qq/
 
 ## see BEGIN block at the bottom for the number of tests and use_ok package check
-
 Log::Log4perl->easy_init(\$ERROR);   
 /);
-
     my @element_names = map {$_->[0]}  @{$elementnodes};
     foreach my $el (@element_names) {
         foreach my $ns (keys %{$self->{_known_class}->{$el}}) {
@@ -1266,19 +1255,15 @@ Log::Log4perl->easy_init(\$ERROR);
             }
         }
     }
-    $self->sayIt("#", $test_number++);
-   
+    $self->sayIt("#", $test_number++);  
     $self->sayIt('critic_ok("$Bin/../' .  $self->project_root . "/" . $self->datatypes_root . "/" . 
-                                  $self->{_schema_version_dir} . "/$ns" .  
-				  $self->_dirPath . '.pm", "perl critic have not found any problems") 
-	            or diag(" perl critic found problems ");');
-  
-    
-    my $accessors =   'get_nsmap get_idmap ' . join(' ',  map{"get_$_"}  @{$attributes}, @element_names);
-     
+                 $self->{_schema_version_dir} . "/$ns" .  
+		 $self->_dirPath . '.pm", "perl critic have not found any problems") 
+	         or diag(" perl critic found problems ");');
+   
+    my $accessors =   'get_nsmap get_idmap ' . join(' ',  map{"get_$_"}  @{$attributes}, @element_names);     
     $self->sayIt("#", $test_number++);
-    $self->sayIt("can_ok($className->new(), qw/$accessors/);");
-     
+    $self->sayIt("can_ok($className->new(), qw/$accessors/);");     
     $self->sayIt(qq/
 
 my \$obj1 = undef;
@@ -1325,7 +1310,6 @@ eval {
     $self->sayIt('ok($string && !$EVAL_ERROR, "Converting to XML string: $string") or diag($EVAL_ERROR);');
     $self->sayIt('undef $EVAL_ERROR;');
     $self->sayIt('#', ++$test_number);
-
     $self->sayIt('my $obj22;');
     $self->sayIt('eval {');
     $self->sayIt("    \$obj22 = $className->new({xml => \$string});");
@@ -1362,7 +1346,6 @@ BEGIN {
 #             $name - name of the current element - will be used as parent DOM object identifier for recursive call
 #             $logic - conditional logic parsed by _conditionParser
 #
-#
 sub _printGetArrayDom {
     my ($self, $subname, $name, $logic) = @_;
     $self->sayIt(qq/
@@ -1442,28 +1425,31 @@ sub  _printConditional {
     my $fromDomArg = ($key ne 'text')?"\$dom->getAttribute('$key')":"\$dom->textContent";
 
     my  $condition  = _conditionParser($value);
-    print("$value Enum List:: " . ( join ":", map { " $_= " . $condition->{$_}} keys  %{$condition})) if $self->DEBUG > 0 && !$condition->{condition}  eq 'scalar';
+    print("$value Enum List:: " . ( join ":", map { " $_= " . $condition->{$_}} keys  %{$condition})) 
+        if $self->DEBUG > 0 && !$condition->{condition}  eq 'scalar';
 
     if($condition->{condition}   eq 'scalar') {
-        $string =   $what eq 'get'?"                                                     $arrayref_signleft'$key' =>  \$self->$what\_$key$arrayref_signright,\n":
-                                 "    \$self->$what\_$key($fromDomArg) if($fromDomArg);\n";
+        $string =   $what eq 'get'?
+	                "                                                     $arrayref_signleft'$key' =>  \$self->$what\_$key$arrayref_signright,\n":
+                        "    \$self->$what\_$key($fromDomArg) if($fromDomArg);\n";
     } elsif($condition->{condition}  =~ /^if|unless$/ &&  $condition->{logic}) {
-        $string =  $what eq 'get'?"                                           $arrayref_signleft '$key' => (".$condition->{logic}."?\$self->$what\_$key:undef)$arrayref_signright,\n":
-                                 "    \$self->$what\_$key($fromDomArg) if(" . $condition->{logic}. " && $fromDomArg);\n";
-    }elsif($condition->{condition} =~ /enum|set|exclude/ &&  $condition->{regexp}) {
+        $string =  $what eq 'get'?
+	               "                                           $arrayref_signleft '$key' => (".$condition->{logic}."?\$self->$what\_$key:undef)$arrayref_signright,\n":
+                       "    \$self->$what\_$key($fromDomArg) if(" . $condition->{logic}. " && $fromDomArg);\n";
+    } elsif($condition->{condition} =~ /enum|set|exclude/ &&  $condition->{regexp}) {
 
-    my $regexp  =  $what eq 'get'?"(\$self->$what\_$key   " . $condition->{regexp} . ")":"($fromDomArg  " . $condition->{regexp}  .")";
-
-    $string =   $what eq 'get'?"                                           $arrayref_signleft'$key' =>  ($regexp?\$self->$what\_$key:undef)$arrayref_signright,\n":
-                                 "    \$self->$what\_$key($fromDomArg) if($fromDomArg && $regexp);\n";
+        my $regexp  =  $what eq 'get'?
+	                    "(\$self->$what\_$key   " . $condition->{regexp} . ")":
+			    "($fromDomArg  " . $condition->{regexp}  .")";
 
+        $string =  $what eq 'get'?
+	           "                                           $arrayref_signleft'$key' =>  ($regexp?\$self->$what\_$key:undef)$arrayref_signright,\n":
+                   "    \$self->$what\_$key($fromDomArg) if($fromDomArg && $regexp);\n";
     } else {
         croak("Malformed , unknown condition=" . $condition->{condition} );
     }
-
     return $string;
 }
-
 #
 #   auxiliary private function ( extracted from the build_class )
 #   returns string with value setting statements for mapped sql fields
@@ -1509,7 +1495,8 @@ sub _printFromDOM {
     my ($self, $subname, $el, $type, $conditon_head, $cond_string) = @_;
     my  $subnameUP =  ucfirst($subname);
     my $ns = $el->{'attrs'}{'xmlns'};
-    print "Building fromDOM: type=$type subname=$subname   head=$conditon_head  string=$cond_string ns=$ns  class=" . $self->{_known_class}->{$subname}{ $ns } ."\n" if $self->DEBUG > 2;
+    print "Building fromDOM: type=$type subname=$subname   head=$conditon_head  string=$cond_string ns=$ns  class=" . $self->{_known_class}->{$subname}{ $ns } ."\n" 
+        if $self->DEBUG > 2;
     $self->sayIt("   $conditon_head ($cond_string\$tagname eq  '$subname' && \$nsid eq '".  $el->{'attrs'}{'xmlns'}  ."' && \$self->can(\"get_\$tagname\")) {");
     $self->sayIt("                eval {");
     $self->sayIt("                    \$element = " . $self->{_known_class}->{$subname}{$el->{'attrs'}{'xmlns'}} . "->new(\$childnode)");
@@ -1560,18 +1547,19 @@ sub sayIt {
 sub _printHelpers {
     my ($self) = @_;
     my $root_package =  $self->project_root . '::' .  $self->datatypes_root . '::' . $self->{_schema_version_dir};
-    mkpath   ([ $self->top_dir . '/' . $self->project_root . '/' . $self->datatypes_root . '/' .  $self->{_schema_version_dir} ], 1, 0755);
-    $self->_fh(IO::File->new( $self->top_dir .  "/" . $self->project_root . '/' . $self->datatypes_root . "/" .  $self->{_schema_version_dir} ."/Element.pm" ,"w+"));
-    croak("Failed to open Element.pm file")  unless  $self->_fh;
+    mkpath   ([$self->top_dir . '/' . $self->project_root . '/' . 
+               $self->datatypes_root . '/' .  $self->{_schema_version_dir} ], 1, 0755);
+    $self->_fh(IO::File->new($self->top_dir .  "/" . $self->project_root . '/' . 
+                             $self->datatypes_root . "/" .  $self->{_schema_version_dir} ."/Element.pm" ,"w+"));
+    croak("Failed to open Element.pm file") 
+        unless  $self->_fh;
     my $registry_string;   
     foreach my $prefix (keys %{$self->nsregistry}) {
         $registry_string .= " '$prefix' => '" . $self->nsregistry->{$prefix} . "',\n";
     }
     # define packages
     my $element_package = "$root_package\:\:Element";
- 
     my $nsmap_package = "$root_package\:\:NSMap";
-
     my $version = $self->schema_version; 
 
 ##########   printing Element.pm
@@ -1599,7 +1587,6 @@ use Readonly;
 use Scalar::Util qw(blessed);
 use XML::LibXML;
 use Log::Log4perl qw(get_logger);
- 
 use Data::Dumper;
 Readonly::Scalar our \$CLASSPATH =>  '$element_package';
 Readonly::Hash   our %NSREGISTRY => ($registry_string);
@@ -1608,7 +1595,6 @@ our \$LOGGER = get_logger(\$CLASSPATH);
 
 \=head1 METHODS
 
-
 \=head2    getElement ()
 
  create   element from some data struct and return it as DOM
@@ -1645,42 +1631,42 @@ sub  getElement {
     my \$nss =    \$param->{ns}; ## reference to array ref with ns prefixes for this element
    
     if(\$param->{parent} && blessed(\$param->{parent}) && \$param->{parent}->isa('XML::LibXML::Document')) {
-            \$data =  \$param->{parent}->createElement(\$name);
+        \$data =  \$param->{parent}->createElement(\$name);
     } else {
-            \$data =  XML::LibXML::Element->new(\$name);
+        \$data =  XML::LibXML::Element->new(\$name);
     }
     ## validation of the namespace prefixes  registered
     if(\$nss)  {
-            foreach my \$ns (\@{\$nss}) {
-                next unless \$ns;
-                unless(\$NSREGISTRY{\$ns}) {
-		    \$LOGGER->error("Attempted to create element with un-supported namespace prefix"); 
-		}
-                \$data->setNamespace(\$NSREGISTRY{\$ns}, \$ns, 1);
-            }
+        foreach my \$ns (\@{\$nss}) {
+            next unless \$ns;
+            unless(\$NSREGISTRY{\$ns}) {
+     	 	\$LOGGER->error("Attempted to create element with un-supported namespace prefix"); 
+     	    }
+            \$data->setNamespace(\$NSREGISTRY{\$ns}, \$ns, 1);
+        }
     } else {
-            \$LOGGER->error("Attempted to create element without namespace");
+        \$LOGGER->error("Attempted to create element without namespace");
     }
-    if ((\$attrs && ref(\$attrs) eq 'ARRAY') || \$text) {
-            if(\$attrs && ref(\$attrs) eq 'ARRAY') {
-                foreach my \$attr (\@{\$attrs}) {
-                    if(\$attr->[0] && \$attr->[1]) {
-                        unless(ref(\$attr->[1]))   {
-                            \$data->setAttribute(\$attr->[0], \$attr->[1]);
-                        } else {
-                            \$LOGGER->warn("Attempted to create ".\$attr->[0]." with this: ".\$attr->[1]." dump:" . sub { Dumper(\$attr->[1])});
-                        }
-                    }
-                }
+    if((\$attrs && ref(\$attrs) eq 'ARRAY') || \$text) {
+        if(\$attrs && ref(\$attrs) eq 'ARRAY') {
+            foreach my \$attr (\@{\$attrs}) {
+        	if(\$attr->[0] && \$attr->[1]) {
+        	    unless(ref(\$attr->[1]))   {
+        		\$data->setAttribute(\$attr->[0], \$attr->[1]);
+        	    } else {
+        		\$LOGGER->warn("Attempted to create ".\$attr->[0]." with this: ".\$attr->[1]." dump:" . sub { Dumper(\$attr->[1])});
+        	    }
+        	}
             }
-            if(\$text)  {
-                unless(ref(\$text)) {
-                    my \$text_el = XML::LibXML::Text->new(\$text);
-                    \$data->appendChild(\$text_el);
-                }  else {
-                    \$LOGGER->warn(" Attempted to create text with non scalar: \$text dump:" . sub {Dumper(\$text)});
-                }
+        }
+        if(\$text)  {
+            unless(ref(\$text)) {
+        	my \$text_el = XML::LibXML::Text->new(\$text);
+        	\$data->appendChild(\$text_el);
+            }  else {
+        	\$LOGGER->warn(" Attempted to create text with non scalar: \$text dump:" . sub {Dumper(\$text)});
             }
+        }
     } else {
         \$LOGGER->warn(" Attempted to create empty element with name \$name, failed to do so, will return undef ");
     }
@@ -1689,10 +1675,10 @@ sub  getElement {
 /);
 
     $self->sayIt($self->footer->asString());
- 
-    $self->_fh(IO::File->new( $self->top_dir .  "/" . $self->project_root .  "/" . $self->datatypes_root  . "/" .  $self->{_schema_version_dir} . "/NSMap.pm" ,"w+"));
-    croak(" Failed to open NSMap.pm file")  unless  $self->_fh;
-
+    $self->_fh(IO::File->new($self->top_dir .  "/" . $self->project_root .  "/" . 
+                             $self->datatypes_root  . "/" .  $self->{_schema_version_dir} . "/NSMap.pm" ,"w+"));
+    croak(" Failed to open NSMap.pm file") 
+        unless  $self->_fh;
     $self->sayIt(qq/package   $nsmap_package;
 
 use strict;
@@ -1753,7 +1739,6 @@ sub new {
     return \$self;
 }
 
-
 \=head2 mapname()
 
     maps localname on the prefix
@@ -1765,11 +1750,10 @@ sub new {
 
 \=cut
 
-
 sub mapname {
     my (\$self, \$element, \$nsid) = \@_;
     if (\$element && \$nsid) {
-        \$self->{nsmap}->{\$element}  =  \$nsid;
+        \$self->{nsmap}->{\$element} = \$nsid;
     return \$self;
     } elsif(\$element && \$self->{nsmap}->{\$element} && !\$nsid) {
         return \$self->{nsmap}->{\$element};
